@@ -4,7 +4,7 @@
 
 (eval '(run-hooks 'mh-e-load-hook))
 
-(defconst mh-e-time-stamp "Time-stamp: <95/10/30 19:14:06 gildea>")
+(defconst mh-e-time-stamp "Time-stamp: <00/05/08 15:21:51 aj>")
 (defconst mh-e-version "5.0.2"
   "Version numbers of this version of mh-e.")
 
@@ -65,7 +65,7 @@
 ;;; Modified by James Larus, BBN, July 1984 and UCB, 1984 & 1985.
 ;;; Rewritten for GNU Emacs, James Larus 1985.  larus@ginger.berkeley.edu
 ;;; Modified by Stephen Gildea 1988.  gildea@lcs.mit.edu
-(defconst mh-e-RCS-id "$Id: mh-e.el,v 3.22.1.4 95/10/31 00:14:39 gildea Exp $")
+(defconst mh-e-RCS-id "$Id: mh-e.el,v 1.2 2000/05/08 13:24:54 andreasj Exp $")
 
 ;;; Code:
 
@@ -445,7 +445,7 @@ previous refile or write command."
 Start by running mh-before-quit-hook.  Restore the previous window
 configuration, if one exists.  Finish by running mh-quit-hook."
   (interactive)
-  (run-hooks 'mh-before-quit-hook) 
+  (run-hooks 'mh-before-quit-hook)
   (mh-update-sequences)
   (mh-invalidate-show-buffer)
   (bury-buffer (current-buffer))
@@ -903,6 +903,9 @@ The value of mh-folder-mode-hook is called when a new folder is set up."
 	    ((looking-at "scan: "))	; Keep error messages
 	    (t
 	     (keep-lines mh-valid-scan-line))) ; Flush random scan lines
+      ;; Make sure mh-msg-count has the correct value, so that code
+      ;; depending on it (e.g., mh-goto-msg) works.
+      (setq mh-msg-count (count-lines (point-min) (point-max)))
       (setq mh-seq-list (mh-read-folder-sequences folder nil))
       (mh-notate-user-sequences)
       (or update
